/// <reference types="node" />
import rspack from '@rspack/core';
import type { Server } from '@callstack/repack-dev-server';
import type { Reporter } from '../logging';
import type { StartCliOptions, HMRMessageBody } from '../types';
import type { CompilerAsset, MultiWatching } from './types';
export declare class Compiler {
    private cliOptions;
    private reporter;
    instance: rspack.MultiCompiler;
    platforms: string[];
    assetsCache: Record<string, Record<string, CompilerAsset> | undefined>;
    statsCache: Record<string, rspack.StatsCompilation | undefined>;
    resolvers: Record<string, Array<(error?: Error) => void>>;
    isCompilationInProgress: Record<string, boolean>;
    watchOptions: rspack.WatchOptions;
    watching: MultiWatching | null;
    constructor(cliOptions: StartCliOptions, reporter: Reporter);
    private getCompilerForPlatform;
    private callPendingResolvers;
    private configureCompilerForPlatform;
    init(ctx: Server.DelegateContext): Promise<void>;
    start(): void;
    getAsset(filename: string, platform: string): Promise<CompilerAsset>;
    getSource(filename: string, platform?: string): Promise<string | Buffer>;
    getSourceMap(filename: string, platform: string): Promise<string | Buffer>;
    getMimeType(filename: string): string;
    getHmrBody(platform: string): HMRMessageBody | null;
}
