"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DevelopmentPlugin = void 0;
var _core = _interopRequireDefault(require("@rspack/core"));
var _pluginReactRefresh = _interopRequireDefault(require("@rspack/plugin-react-refresh"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * {@link DevelopmentPlugin} configuration options.
 */

/**
 * Class for running development server that handles serving the built bundle, all assets as well as
 * providing Hot Module Replacement functionality.
 *
 * @category Webpack Plugin
 */
class DevelopmentPlugin {
  /**
   * Constructs new `DevelopmentPlugin`.
   *
   * @param config Plugin configuration options.
   */
  constructor(config) {
    this.config = config;
  }

  /**
   * Apply the plugin.
   *
   * @param compiler Webpack compiler instance.
   */
  apply(compiler) {
    if (!this.config?.devServer) {
      return;
    }
    new _core.default.DefinePlugin({
      __PUBLIC_PORT__: JSON.stringify(this.config.devServer.port),
      __PLATFORM__: JSON.stringify(this.config.platform)
    }).apply(compiler);
    if (this.config?.devServer.hmr) {
      // TODO Align this with output.hotModuleUpdateChunkFilename?
      // setup HMR source maps
      new _core.default.SourceMapDevToolPlugin({
        test: /\.hot-update\.js$/,
        filename: '[file].map',
        append: `//# sourceMappingURL=[url]?platform=${this.config.platform}`,
        module: true,
        columns: true,
        noSources: false
      }).apply(compiler);

      // setup HMR
      new _core.default.HotModuleReplacementPlugin().apply(compiler);
      new _pluginReactRefresh.default().apply(compiler);
      new _core.default.EntryPlugin(compiler.context, require.resolve('../../modules/WebpackHMRClient'), {
        name: undefined
      }).apply(compiler);

      // TODO Bring back lazy compilation when it's implemented in rspack
    }
  }
}
exports.DevelopmentPlugin = DevelopmentPlugin;
//# sourceMappingURL=DevelopmentPlugin.js.map