import rspack, { RspackPluginInstance } from '@rspack/core';
import type { DevServerOptions } from '../../../types';
/**
 * {@link RepackTargetPlugin} configuration options.
 */
export interface RepackTargetPluginConfig extends Pick<DevServerOptions, 'hmr'> {
    /**
     * Absolute location to JS file with initialization logic for React Native.
     * Useful if you want to built for out-of-tree platforms.
     */
    initializeCoreLocation?: string;
}
/**
 * Plugin for tweaking the JavaScript runtime code to account for React Native environment.
 *
 * Globally available APIs differ with React Native and other target's like Web, so there are some
 * tweaks necessary to make the final bundle runnable inside React Native's JavaScript VM.
 *
 * @category Webpack Plugin
 */
export declare class RepackTargetPlugin implements RspackPluginInstance {
    private config?;
    /**
     * Constructs new `RepackTargetPlugin`.
     *
     * @param config Plugin configuration options.
     */
    constructor(config?: RepackTargetPluginConfig | undefined);
    private getReactNativePath;
    /**
     * Apply the plugin.
     *
     * @param compiler Webpack compiler instance.
     */
    apply(compiler: rspack.Compiler): void;
}
